@@ -44,7 +44,7 @@
 using namespace UCOMMON_NAMESPACE;
 using namespace std;
 
-StreamProtocol::StreamProtocol() :
+StreamBuffer::StreamBuffer() :
 streambuf(),
 #ifdef OLD_STDCPP
     iostream()
@@ -59,17 +59,7 @@ streambuf(),
 #endif
 }
 
-int StreamProtocol::overflow(int code)
-{
-    return _putch(code);
-}
-
-int StreamProtocol::underflow()
-{
-    return _getch();
-}
-
-int StreamProtocol::uflow()
+int StreamBuffer::uflow()
 {
     int ret = underflow();
 
@@ -82,7 +72,7 @@ int StreamProtocol::uflow()
     return ret;
 }
 
-void StreamProtocol::allocate(size_t size)
+void StreamBuffer::allocate(size_t size)
 {
     if(gbuf)
         delete[] gbuf;
@@ -109,7 +99,7 @@ void StreamProtocol::allocate(size_t size)
     setp(pbuf, pbuf + size);
 }
 
-void StreamProtocol::release(void)
+void StreamBuffer::release(void)
 {
     if(gbuf)
         delete[] gbuf;
@@ -122,7 +112,7 @@ void StreamProtocol::release(void)
     clear();
 }
 
-int StreamProtocol::sync(void)
+int StreamBuffer::sync(void)
 {
     if(!bufsize)
         return 0;
@@ -133,29 +123,29 @@ int StreamProtocol::sync(void)
 }
 
 tcpstream::tcpstream(const tcpstream &copy) :
-StreamProtocol()
+StreamBuffer()
 {
-    so = Socket::create(Socket::getfamily(copy.so), SOCK_STREAM, IPPROTO_TCP);
+    so = Socket::create(Socket::family(copy.so), SOCK_STREAM, IPPROTO_TCP);
     timeout = copy.timeout;
 }
 
 tcpstream::tcpstream(int family, timeout_t tv) :
-StreamProtocol()
+StreamBuffer()
 {
     so = Socket::create(family, SOCK_STREAM, IPPROTO_TCP);
     timeout = tv;
 }
 
 tcpstream::tcpstream(Socket::address& list, unsigned segsize, timeout_t tv) :
-StreamProtocol()
+StreamBuffer()
 {
-    so = Socket::create(list.getfamily(), SOCK_STREAM, IPPROTO_TCP);
+    so = Socket::create(list.family(), SOCK_STREAM, IPPROTO_TCP);
     timeout = tv;
     open(list);
 }
 
 tcpstream::tcpstream(const TCPServer *server, unsigned segsize, timeout_t tv) :
-StreamProtocol()
+StreamBuffer()
 {
     so = server->accept();
     timeout = tv;
@@ -173,7 +163,7 @@ tcpstream::~tcpstream()
 
 void tcpstream::release(void)
 {
-    StreamProtocol::release();
+    StreamBuffer::release();
     Socket::release(so);
 }
 
@@ -199,7 +189,7 @@ ssize_t tcpstream::_write(const char *buffer, size_t size)
     return Socket::sendto(so, buffer, size);
 }
 
-int tcpstream::_getch(void)
+int tcpstream::underflow(void)
 {
     ssize_t rlen = 1;
     unsigned char ch;
@@ -246,7 +236,7 @@ int tcpstream::_getch(void)
     return (unsigned char) *gptr();
 }
 
-int tcpstream::_putch(int c)
+int tcpstream::overflow(int c)
 {
     unsigned char ch;
     ssize_t rlen, req;
@@ -310,7 +300,7 @@ void tcpstream::open(const char *host, const char *service, unsigned mss)
     if(bufsize)
         close();
 
-    struct addrinfo *list = Socket::getaddress(host, service, SOCK_STREAM, 0);
+    struct addrinfo *list = Socket::query(host, service, SOCK_STREAM, 0);
     if(!list)
         return;
 
@@ -408,16 +398,16 @@ void tcpstream::allocate(unsigned mss)
         Socket::sendwait(so, mss * 4);
 
 allocate:
-    StreamProtocol::allocate(size);
+    StreamBuffer::allocate(size);
 }
 
 pipestream::pipestream() :
-StreamProtocol()
+StreamBuffer()
 {
 }
 
 pipestream::pipestream(const char *cmd, access_t access, char **args, char **envp, size_t size) :
-StreamProtocol()
+StreamBuffer()
 {
     open(cmd, access, args, envp, size);
 }
@@ -443,7 +433,7 @@ void pipestream::release(void)
     if(pbuf)
         fsys::release(wr);
 
-    StreamProtocol::release();
+    StreamBuffer::release();
 }
 
 void pipestream::allocate(size_t size, access_t mode)
@@ -477,7 +467,7 @@ void pipestream::allocate(size_t size, access_t mode)
         setp(pbuf, pbuf + size);
 }
 
-int pipestream::_getch(void)
+int pipestream::underflow(void)
 {
     ssize_t rlen = 1;
     unsigned char ch;
@@ -486,7 +476,7 @@ int pipestream::_getch(void)
         return EOF;
 
     if(bufsize == 1) {
-        rlen = fsys::read(rd, &ch, 1);
+        rlen = rd.read(&ch, 1);
         if(rlen < 1) {
             if(rlen < 0)
                 close();
@@ -502,7 +492,7 @@ int pipestream::_getch(void)
         return (unsigned char)*gptr();
 
     rlen = (ssize_t)((gbuf + bufsize) - eback());
-    rlen = fsys::read(rd, eback(), rlen);
+    rlen = rd.read(eback(), rlen);
     if(rlen < 1) {
 //      clear(ios::failbit | rdstate());
         if(rlen < 0)
@@ -516,7 +506,7 @@ int pipestream::_getch(void)
     return (unsigned char) *gptr();
 }
 
-int pipestream::_putch(int c)
+int pipestream::overflow(int c)
 {
     unsigned char ch;
     ssize_t rlen, req;
@@ -529,7 +519,7 @@ int pipestream::_putch(int c)
             return 0;
 
         ch = (unsigned char)(c);
-        rlen = fsys::write(wr, &ch, 1);
+        rlen = wr.write(&ch, 1);
         if(rlen < 1) {
             if(rlen < 0)
                 close();
@@ -544,7 +534,7 @@ int pipestream::_putch(int c)
 
     req = (ssize_t)(pptr() - pbase());
     if(req) {
-        rlen = fsys::write(wr, pbase(), req);
+        rlen = wr.write(pbase(), req);
         if(rlen < 1) {
             if(rlen < 0)
                 close();
@@ -586,7 +576,7 @@ void pipestream::open(const char *path, access_t mode, char **args, char **envp,
         fsys::inherit(input, false);
     }
     else
-        stdio[1] = fsys::nullfile();
+        stdio[1] = fsys::null();
 
     if(mode == WRONLY || mode == RDWR) {
         if(fsys::pipe(stdio[0], output)) {
@@ -599,7 +589,7 @@ void pipestream::open(const char *path, access_t mode, char **args, char **envp,
         }
     }
     else
-        stdio[0] = fsys::nullfile();
+        stdio[0] = fsys::null();
 
     pid = shell::spawn(path, args, envp, stdio);
 
@@ -628,12 +618,12 @@ int pipestream::close(void)
 }
 
 filestream::filestream() :
-StreamProtocol()
+StreamBuffer()
 {
 }
 
 filestream::filestream(const filestream& copy) :
-StreamProtocol()
+StreamBuffer()
 {
     if(copy.bufsize)
         fd = copy.fd;
@@ -641,17 +631,16 @@ StreamProtocol()
         allocate(copy.bufsize, copy.ac);
 }
 
-
 filestream::filestream(const char *filename, fsys::access_t mode, size_t size) :
-StreamProtocol()
+StreamBuffer()
 {
     open(filename, mode, size);
 }
 
-filestream::filestream(const char *filename, fsys::access_t access, unsigned mode, size_t size) :
-StreamProtocol()
+filestream::filestream(const char *filename, unsigned mode, fsys::access_t access, size_t size) :
+StreamBuffer()
 {
-    create(filename, access, mode, size);
+    open(filename, mode, access, size);
 }
 
 filestream::~filestream()
@@ -663,7 +652,7 @@ void filestream::seek(fsys::offset_t offset)
 {
     if(bufsize) {
         sync();
-        fsys::seek(fd, offset);
+        fd.seek(offset);
     }
 }
 
@@ -672,9 +661,9 @@ void filestream::close(void)
     sync();
 
     if(bufsize)
-        fsys::close(fd);
+        fd.close();
 
-    StreamProtocol::release();
+    StreamBuffer::release();
 }
 
 void filestream::allocate(size_t size, fsys::access_t mode)
@@ -693,26 +682,26 @@ void filestream::allocate(size_t size, fsys::access_t mode)
         return;
     }
 
-    if(mode == fsys::ACCESS_RDONLY || fsys::ACCESS_RDWR || fsys::ACCESS_SHARED || fsys::ACCESS_DIRECTORY)
+    if(mode == fsys::RDONLY || fsys::RDWR || fsys::SHARED)
         gbuf = new char[size];
-    if(mode == fsys::ACCESS_WRONLY || fsys::ACCESS_APPEND || fsys::ACCESS_SHARED || fsys::ACCESS_RDWR)
+    if(mode == fsys::WRONLY || fsys::APPEND || fsys::SHARED || fsys::RDWR)
         pbuf = new char[size];
     bufsize = size;
     clear();
-    if(mode == fsys::ACCESS_RDONLY || fsys::ACCESS_RDWR || fsys::ACCESS_SHARED || fsys::ACCESS_DIRECTORY) {
+    if(mode == fsys::RDONLY || fsys::RDWR || fsys::SHARED) {
 #if (defined(__GNUC__) && (__GNUC__ < 3)) && !defined(MSWINDOWS) && !defined(STLPORT)
         setb(gbuf, gbuf + size, 0);
 #endif
         setg(gbuf, gbuf + size, gbuf + size);
     }
-    if(mode == fsys::ACCESS_WRONLY || fsys::ACCESS_APPEND || fsys::ACCESS_SHARED || fsys::ACCESS_RDWR)
+    if(mode == fsys::WRONLY || fsys::APPEND || fsys::SHARED || fsys::RDWR)
         setp(pbuf, pbuf + size);
 }
 
-void filestream::create(const char *fname, fsys::access_t access, unsigned mode, size_t size)
+void filestream::open(const char *fname, unsigned fmode, fsys::access_t access, size_t size)
 {
     close();
-    fsys::create(fd, fname, access, mode);
+    fd.open(fname, fmode, access);
     if(is(fd))
         allocate(size, access);
 }
@@ -720,12 +709,12 @@ void filestream::create(const char *fname, fsys::access_t access, unsigned mode,
 void filestream::open(const char *fname, fsys::access_t access, size_t size)
 {
     close();
-    fsys::open(fd, fname, access);
+    fd.open(fname, access);
     if(is(fd))
         allocate(size, access);
 }
 
-int filestream::_getch(void)
+int filestream::underflow(void)
 {
     ssize_t rlen = 1;
 
@@ -739,7 +728,7 @@ int filestream::_getch(void)
         return (unsigned char)*gptr();
 
     rlen = (ssize_t)((gbuf + bufsize) - eback());
-    rlen = fsys::read(fd, eback(), rlen);
+    rlen = fd.read(eback(), rlen);
     if(rlen < 1) {
 //      clear(ios::failbit | rdstate());
         if(rlen < 0)
@@ -753,7 +742,7 @@ int filestream::_getch(void)
     return (unsigned char) *gptr();
 }
 
-int filestream::_putch(int c)
+int filestream::overflow(int c)
 {
     ssize_t rlen, req;
 
@@ -765,7 +754,7 @@ int filestream::_putch(int c)
 
     req = (ssize_t)(pptr() - pbase());
     if(req) {
-        rlen = fsys::write(fd, pbase(), req);
+        rlen = fd.write(pbase(), req);
         if(rlen < 1) {
             if(rlen < 0)
                 close();
@@ -788,5 +777,76 @@ int filestream::_putch(int c)
     return c;
 }
 
+std::istream& _stream_operators::input(std::istream& inp, InputProtocol& fmt)
+{
+    int c = 0;
+    while(!c) {
+        if(!inp.good())
+            c = EOF;
+        else
+            c = inp.get();
+
+        c = fmt._input(c);
+        if(!c)
+            continue;
+        if(c != EOF)
+            inp.putback(c);
+    }
+    return inp;
+}
+
+std::ostream& _stream_operators::print(std::ostream& out, const PrintProtocol& fmt)
+{
+    if(out.good()) {
+        const char *cp = fmt._print();
+
+        if(cp)
+            out.write(cp, strlen(cp));
+        else
+            out << std::endl;
+    }
+    return out;
+}
+
+std::istream& _stream_operators::input(std::istream& inp, string_t& str)
+{
+    inp.getline(str.c_mem(), str.size());
+    return inp;
+}
+
+std::ostream& _stream_operators::print(std::ostream& out, const string_t& str)
+{
+    out.write(str.c_str(), str.len());
+    return out;
+}
+
+std::istream& _stream_operators::input(std::istream& inp, stringlist_t& list)
+{
+    size_t size = list.size() - 64;
+
+    char *tmp = (char *)malloc(size);
+    while(inp.good()) {
+        inp.getline(tmp, size);
+        if(!list.filter(tmp, size))
+            break;
+    }
+    free(tmp);
+    return inp;
+}
+
+std::ostream& _stream_operators::print(std::ostream& out, const stringlist_t& list)
+{
+    StringPager::iterator sp = list.begin();
+    while(is(sp) && out.good()) {
+        const char *cp = sp->get();
+        size_t size = strlen(cp);
+        if(size)
+            out.write(cp, size);
+        out.put('\n');
+        sp.next();
+    }
+    return out;
+}
+
 #endif
 
