@@ -81,6 +81,11 @@ protected:
      * Handler to invoke in derived class when accessing outside the
      * shared memory segment boundary.
      */
+    virtual void *invalid(void) const;
+
+    /**
+     * Handler for failure to map (allocate) memory.
+     */
     virtual void fault(void) const;
 
 public:
@@ -154,8 +159,9 @@ public:
      * @param offset from start of segment.
      * @param buffer to copy into.
      * @param size of object to copy.
+     * @return true on success.
      */
-    void copy(size_t offset, void *buffer, size_t size) const;
+    bool copy(size_t offset, void *buffer, size_t size) const;
 
     /**
      * Get size of mapped segment.
@@ -168,7 +174,7 @@ public:
      * Get starting address of mapped segment.
      * @return starting address of mapped segment.
      */
-    inline caddr_t getStart(void)
+    inline caddr_t addr(void)
         {return map;};
 
     /**
@@ -329,7 +335,7 @@ public:
      * Get member size of typed objects that can be held in mapped vector.
      * @return members mapped in segment.
      */
-    inline unsigned getSize(void)
+    inline unsigned max(void)
         {return (unsigned)(size / sizeof(T));};
 };
 
@@ -490,14 +496,14 @@ public:
     inline volatile const T *get(unsigned member)
         {return static_cast<const T*>(offset(member * sizeof(T)));};
 
-    inline void copy(unsigned member, T *buffer)
-        {MappedMemory::copy(member * sizeof(T), buffer, sizeof(T));};
+    inline void copy(unsigned member, T& buffer)
+        {MappedMemory::copy(member * sizeof(T), &buffer, sizeof(T));};
 
     /**
      * Get count of typed member objects held in this map.
      * @return count of typed member objects.
      */
-    inline unsigned getCount(void)
+    inline unsigned count(void)
         {return (unsigned)(size / sizeof(T));};
 };
 
