@@ -47,7 +47,7 @@ int main(int argc, char *argv[])
     char line[200];
     TCPServer sock("127.0.0.1", "9000");
     thread.start();
-    if (sock.waitConnection(1000)){
+    if (sock.wait(1000)){
         tcpstream tcp(&sock);
         tcp.getline(line, 200);
         assert(!strcmp(line, "pippo"));
